#------------------------------------------------------------------------------
# kugel.py
#------------------------------------------------------------------------------
# Eine Kugel rollt auf der Leinwand. Wenn sie an eine Seite stößt, prallt sie
# ab und rollt weiter.
# Das wird als "Film" durch aufeinanderfolgende Bilder angezeigt.
# Von der Kommandozeile werden zwei floats dx und dy
# (Änderung der x- bzw. y-Koordinate der Kugel in einem Schritt) gelesen.
#------------------------------------------------------------------------------
import sys, stddraw, random

# Male die Kugel an Stelle position und zeige das Bild an.
def bildAnzeigen(position):
    stddraw.clear(stddraw.YELLOW)
    stddraw.filledCircle(position[0], position[1], 0.05)
    stddraw.show(40)

# Bereite die Leinwand zum Malen vor.
# Die Größe (800x800) und die Malfarbe (rot) werden eingestellt.
def leinwandVorbereiten():
    stddraw.setCanvasSize(800,800)
    stddraw.setPenColor(stddraw.RED)

# Gib 1 zurück, falls 0 < pos < 1, sonst -1.
def randtest(pos):
    if pos>=1.0 or pos<=0.0: return -1
    return 1 

# Bewege die Kugel an Stelle Position einen Schritt in richtung
# und gib die neue Stelle der Kugel zurück.
def bewegeKugel(pos, richtung):
    x_pos = pos[0] + richtung[0]
    y_pos = pos[1] + richtung[1]
    return x_pos, y_pos

# Gib die Richtung zurück, die die Kugel an Stelle position
# einnimmt, wenn sie in Richtung richtung rollt.
# (Die Richtung ändert sich, wenn die Kugel am Rand anstößt.)
def richtungAnpassen(position, richtung):
    dx = randtest(position[0]) * richtung[0]
    dy = randtest(position[1]) * richtung[1]
    return dx, dy

#---- Das HAUPTPROGRAMM  ------------------------------------------------------

# Lies die Richtung der Kugel von der Kommandozeile.
# richtung ist die aktuelle Bewegungsrichtung und Geschwindigkeit der Kugel.
richtung = ( float(sys.argv[1]), float(sys.argv[2]) )

# Die Kugel startet an einer zufällig gewählten Position auf der Leinwand.
# Der Punkt position ist die aktuelle Position der Kugel.
position = ( random.random(), random.random() )

# Leinwandgröße sowie Größe und Farbe der Kugel werden eingestellt.
leinwandVorbereiten()

# Die Bewegung entsteht, indem aufeinanderfolgende Bilder gezeigt werden,
# bei denen die Kugel jedesmal ein kleines Stück weitergerollt ist.
# Bevor die Kugel bewegt wird, muss überprüft werden, ob sie am Rand anstößt
# und dadurch ihre Richtung ändert.
while True:
    # Falls die Kugel an einen Rand prallt, dann ändere ihre x- bzw. y-Richtung.
    richtung = richtungAnpassen(position, richtung)
    # Bestimme die nächste Position der Kugel.
    position = bewegeKugel(position, richtung)
    # Lösche die Leinwand, male die Kugel auf ihrer neuen Position und zeige die Leinwand an.
    bildAnzeigen(position)

#-------------------------------------------------------------------------------
# python3 kugel.py 0.005 0.008
#
# python3 kugel.py 0.005 0.008
